<?php

namespace App\Http\Controllers\Admin\Services;

use App\Http\Resources\Admin\GroupChatResource;
use App\Http\Resources\Admin\GroupMembersResource;
use App\Http\Resources\PaginationResource;
use App\Models\User;
use App\QueryFilters\CreatedAtFilter;
use App\QueryFilters\CreatorEmailFilter;
use App\QueryFilters\DateRangeFilter;
use App\QueryFilters\StatusFilter;
use App\QueryFilters\TitleFilter;
use App\Services\ChatService;
use Illuminate\Pipeline\Pipeline;
use Mojtaba\Chatable\Models\Group;
use Mojtaba\Chatable\Models\Member;

class GroupChatService
{
    public function index()
    {
        $groups=\app(Pipeline::class)
            ->send(Group::query()->with(['creator.member'=>fn($q)=>$q->withTrashed()]))
            ->through(
                TitleFilter::class,
                CreatorEmailFilter::class,
                            )
            ->thenReturn()
            ->orderBy('created_at','desc')
            ->paginate(30);
        return successResponse(true,
            ['groups'=>new PaginationResource($groups,GroupChatResource::collection($groups->items()))]
        ,"عملیات باموفقیت انجام شد");
    }

    public function addMember($request)
    {
        $chatService=new ChatService();
        return successResponse(true,['members'=>$chatService->addMemberUser($request)]);
    }

    public function deleteMember($groupId,$memberId)
    {
        $member=Member::query()->where('group_id',$groupId)->where('member_id',$memberId)->first();
        if ($member){
            $member->delete();
            return successResponse(true,[]);
        }
        else{
            return  failedResponse('member not found');
        }
    }

    public function delete($groupId)
    {
        $group=Group::query()->where('id',$groupId)->first();
        if ($group){
            $group->delete();
            return onSuccess([]);
        }
        else{
            return  failedResponse('group not found');
        }
    }

    public function members($groupId)
    {
        $group=Group::query()->with('members')->where('id',$groupId)->first();
        if ($group){
            return onSuccess(GroupMembersResource::collection($group->members));
        }
        else{
            return failedResponse("گروه مورد نظر یافت نشد",-404);
        }
    }

}