<?php

namespace App\Http\Controllers\Admin\Structure;

use App\Filter\DateFrom;
use App\Filter\DateTo;
use App\Filter\FilterClass\Estimate\Address;
use App\Filter\FilterClass\Estimate\Email;
use App\Filter\FilterClass\Estimate\EndDate;
use App\Filter\FilterClass\Estimate\ReferenceNumber;
use App\Filter\FilterClass\Estimate\StartDate;
use App\Filter\FilterClass\Estimate\Status;
use App\Http\Controllers\Controller;
use App\Models\Estimate;
use App\Traits\ApiResponser;
use App\Traits\pipeline;
use Illuminate\Http\Request;

class EstimateController extends Controller
{
    use ApiResponser,pipeline;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function __construct()
    {

        $this->middleware(['auth:sanctum', 'isAdmin']);
//
        $this->middleware('can:create-estimate')->only(['store']);
        $this->middleware('can:edit-estimate')->only(['update']);
        $this->middleware('can:read-estimate')->only(['index','show']);
            $this->middleware('can:delete-estimate')->only(['delete']);
    }

    public function index()
    {
        $estimate= $this->pipeline(Estimate::query()->with(['estimateable','lists']),[Email::class
            ,ReferenceNumber::class,Address::class,StartDate::class
            ,EndDate::class,Status::class,DateTo::class,DateFrom::class
        ]);
        return (isset($estimate))?$this->onSuccess($estimate):$this->onFaile('estimate not found');

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

        $estimate=Estimate::query()->where('id',$id)->with('estimateable','lists')->first();
       return ($estimate)?$this->onSuccess($estimate):$this->onFaile('estimate not found');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $estimate = Estimate::find($id);
        return ($estimate)
            ?  $this->onSuccess($estimate->delete()):
            $this->onFaile('estimate not found');
    }
}
