<?php

namespace App\Http\Controllers;

use App\Http\Requests\InvoiceRequest;
use App\Http\Requests\NoteRequest;
use App\Mail\BacancyMail;
use App\Models\Company;
use App\Models\Invoice;
use App\Models\User;
use App\Notifications\InvoiceNotification;
use App\Notifications\NotificationData;
use App\Repositories\InvoiceRepository;
use App\Services\CodeService;
use App\Services\CustomerService;
use App\Services\ListService;
use App\Services\PDFService;
use App\Traits\ApiResponser;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Notification;
use Symfony\Component\HttpFoundation\Response;

class InvoiceController extends Controller
{
    use ApiResponser,NotificationData;
    public $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    public function store($clientRole, InvoiceRequest $invoiceRequest, InvoiceRepository $invoiceRepository,
                          ListService $listService, CustomerService $customerService, CodeService $codeService)
    {
        $data = $invoiceRequest->validated();

        //add image
        $imageName = null;
        if (array_key_exists('image', $data)) {
            $imageController = new ImageController();
            $imageName = $imageController->upload($invoiceRequest->validated()['image']);
        }
        $data['image'] = $imageName;
        $invoiceStore=$invoiceRequest->validated();
        $pdfService = new PDFService();
        $pdf = $pdfService->make($data);
//return $pdf['pdf']->output();

        $invoiceStore['pdf_address']=$pdf['path'];
//return $pdf['path'];
        $client = auth($clientRole)->user();
//        return get_class($client);



        //set referral code
        do {
            $referrenceNumber = $codeService->generateCode();
        } while ($codeService->check(Invoice::class, 'reference_number', $referrenceNumber));


        //add Invoice
        $invoice = $invoiceRepository->store($invoiceStore, $imageName, $referrenceNumber, $client);
//return $Invoice;
        try {
            $email = new EmailController($this->request);
            $email->sendInvoiceEmail($data, $pdf);
        }catch (\Exception $e){
            return $this->failedResponse('No email was sent');

        }
        //add list
        foreach ($invoiceRequest->validated()['list'] as $list) {
            $listService->addList($list, Invoice::class, $invoice->id, $client);
        }


        //send notification
        $user=null;
        if ($data['customer_email'])
        $user=User::where('email', $data['customer_email'])->first()??Company::where('email', $data['customer_email'])->first();
//        return  $user;
        if ($user)
        $client->notify(New InvoiceNotification($this->notificationData($user,'text','title')));


        return successResponse(true, $invoice, 'save Invoice successfully');
    }

    public function show($clientRole, $id, InvoiceRepository $invoiceRepository)
    {
        $client = auth($clientRole)->user();
        $invoice = $invoiceRepository->show($id, $client);
        if ($invoice == null){
            return failedResponse('not found any Invoice', Response::HTTP_NOT_FOUND);
        }
        return successResponse(true, $invoice, 'ok');
    }
    public function showList($clientRole, InvoiceRepository $invoiceRepository)
    {
        $client = auth($clientRole)->user();
        $invoice = $invoiceRepository->showList( $client);
        if ($invoice == null){
            return failedResponse('not found any Invoice', Response::HTTP_NOT_FOUND);
        }
        return successResponse(true, $invoice, 'ok');
    }

    public function delete($clientRole, $id, InvoiceRepository $invoiceRepository, ListService $listService)
    {
        $client = auth($clientRole)->user();
        $invoice = $invoiceRepository->show($id, $client);
        if ($invoice == null) {
            return failedResponse('not found any Invoice', Response::HTTP_OK);
        }

        $invoiceRepository->deleteInvoice($id);
        $listService->delete($id, Invoice::class);

        return successResponse(true, null, 'delete successfully');
    }

    public function addNote($clientRole, $id, NoteRequest $noteRequest, InvoiceRepository $invoiceRepository)
    {
        $client = auth($clientRole)->user();
        $invoice = $invoiceRepository->show($id, $client);
        if ($invoice == null){
            return failedResponse('not found any Invoice to add note', Response::HTTP_OK);
        }
        $invoiceRepository->addNote($id, $noteRequest->validated());

        return successResponse(true, $invoiceRepository->show($id, $client), 'add note successfully');
    }


    public function notif()
    {
        $user = User::query()->first();

        $details = [
            'greeting' => 'Hi Artisan',
            'body' => 'This is my first notification from ItSolutionStuff.com',
            'thanks' => 'Thank you for using ItSolutionStuff.com tuto!',
            'actionText' => 'View My Site',
            'actionURL' => url('/'),
            'order_id' => 101
        ];

        Notification::send($user, new InvoicesNotification($details));
    }
        public function shooooooooooooo(){
            $body = [
                'name'=>'name',
                'url_a'=>'https://www.bacancytechnology.com/',
                'url_b'=>'https://www.bacancytechnology.com/tutorials/laravel',
            ];

            Mail::to(env('FROM_EMAIL'))->send(new BacancyMail($body));
            return back()->with('status','Mail sent successfully');;    }
}
