<?php

namespace App\Http\Controllers\User;

use App\Http\Requests\User\UserRequest;
use App\Http\Controllers\Controller;
use App\Repositories\SocialMediaRepository;
use App\Repositories\User\UserRepository;
use App\Repositories\JobTitleRepository;
use App\Traits\ApiResponser;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Symfony\Component\HttpFoundation\Response;

class UserController extends Controller
{
    use ApiResponser;

    public $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    public function update(UserRequest $userRequest, UserRepository $userRepository)
    {
        //dd($this->request['social_media']);
        //find job id if exists
        $jobId = null;
        if ($this->request['job_title']) {
            $jobRepository = new JobTitleRepository();
            $job = $jobRepository->findJob($this->request['job_title']);
            if ($job == null) {
                return $this->failedResponse('Not Found job', Response::HTTP_NOT_FOUND);
            }
            $jobId = $job->toArray()['id'];
        }

        //upload image
        $imageName = null;
        if ($this->request['image']) {
            $imageName = Carbon::now()->toAtomString() . Str::random(15) . '.' . $this->request->image->extension();
            $this->request->image->storeAs('public/images', $imageName);
        }

        //find user id
        $userId = auth()->user()->toArray()['id'];
        //$user = auth()->user();
        //find social media id
        if ($this->request['social_media']) {
            foreach ($this->request['social_media'] as $key => $media) {
                //dd($key);
                $socialMediaRepository = new SocialMediaRepository();
                $socialMedia = $socialMediaRepository->findSocialMedia($key);

                if ($socialMedia == null) {
                    return $this->failedResponse('Not Found Social Media', Response::HTTP_NOT_FOUND);
                }
                $i = $socialMedia->toArray()['id'];
                $user = $userRepository->findUser($userId);
                //dd($user->socilaMedias());
                //dd('m');
                //$user->socialMedias()->attach($socialMedia, ['link' => $media]); //replace with synce
                $user->socialMedias()->sync([$socialMedia => ['link' => $media]]);
            }
        }

        $user = $userRepository->updateUser($this->request, $userId, $jobId, $imageName);
    }

    public function changePassword(Request $request, $clientRole)
    {
        $client = auth($clientRole)->user();
        if (Hash::check($request->last_password, $client->password)) {
            $client->password = Hash::make($request->new_password);
            $client->save();
            return $this->successResponseWithoutMessage(true, null);
        }
        return failedResponse('wrong password',200);
    }
}
