<?php

namespace App\Http\Requests\Client;


use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class UpdatingSettingRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        $role = auth($request['role'])->user()->toArray();
        if ($request['role'] == 'user') {
            return [
                'first_name' => ['required','alpha','max:255','min:3'],
                'last_name' => ['required','alpha','max:255','min:3'],
                'email' => [
                    'required',
                    'email',
                    Rule::unique('users', 'email')->ignore($role['id'])
                ],
                'image' => 'image|mimes:jpg,png,jpeg,gif,svg|max:2048',
                'phone_number' => ['max:20', 'min:3'],
                'work_experience' => ['numeric','digits:4'],
                'job_title' => ['alpha','max:30','min:3'],
                'about_us' => 'max:600',
                'social_media.*' => ['min:3','max:200'],
            ];
        }
        return [
            'name' => ['required','alpha','max:255','min:3'],
            'email' => [
                'required',
                'email',
                Rule::unique('users', 'email')->ignore($role['id'])
            ],
            'image' => ['image','mimes:jpg,png,jpeg,gif,svg','max:2048'],
            'phone_number' => ['max:20', 'min:3'],
            'about_us' => 'max:600',
            'country' => ['min:2', 'max:60'],
            'social_media.*' => ['min:3','max:200'],
            'owner.first_name' => 'alpha|digit:1',
            'owner.last_name' => ['alpha', 'min:2', 'max:40'],
            'owner.email' => 'email',
            'owner.phone_number' => ['max:20', 'min:3']
        ];
    }
}
